@@ -251,7 +251,7 @@ gpa_settings_selector_menuitem_activate (GtkWidget *widget, gint index)
 	GPANode *settings;
 	gchar *value;
 
-	gpaw = gtk_object_get_data (G_OBJECT (widget), "GPAWidget");
+	gpaw = g_object_get_data (widget, "GPAWidget");
 	g_return_if_fail (gpaw != NULL);
 	g_return_if_fail (GPA_IS_WIDGET (gpaw));
 
