@@ -62,7 +62,7 @@ gpa_spinbutton_get_type (void)
 			NULL, NULL,
 			sizeof (GPASpinbutton),
 			0,
-			(GInstanceInitFunc) gpa_spinbutton_init,
+			(GInstanceInitFunc) gpa_spinbutton_init
 		};
 		type = g_type_register_static (GPA_TYPE_WIDGET, "GPASpinbutton", &info, 0);
 	}
